### Name: perturb
### Title: Data Perturbations based Sensitivity Analysis
### Aliases: perturb
### Keywords: misc optimize

### ** Examples


# Examine the sensitivity of the GLM from Venables & Ripley (2002, p.189)
# as described in the glm module.
# 
# Perturb the two independent variables using +/- 0.025
#       (relative to the size of each observations)
# uniformly distributed noise. Dependent variable is not being modified.
# 
# Summary should show that estimated coefficients are not substantively affected by noise.

data(anorexia,package="MASS")
panorexia = perturb(anorexia, glm, Postwt ~ Prewt + Treat + offset(Prewt),
     family=gaussian, 
    ptb.R=100, ptb.ran.gen=c(PTBi,PTBus,PTBus), ptb.s=c(1,.005,.005) )
summary(panorexia)

# Use classic longley dataset. The model is numerically unstable, 
# and much more sensitive to noise.  Smaller amounts of noise tremendously
# alter some of the estimated coefficients:
# 
# In this example we are not perturbing the dependent variable (employed) or 
# the year variable. So we assign then PTBi or NULL in ptb.ran.gen )

data(longley)
plongley = perturb(longley,lm,Employed~.) # defaults

# Alternatively, choose specific perturbation functions
#
#plongley = perturb(longley,lm,Employed~., ptb.R=100, 
#    ptb.ran.gen=c(PTBi, replicate(5,PTBus),PTBi), ptb.s=c(1,replicate(5,.001),1))

# summarizes range
sp=summary(plongley)
print(sp)
plot(sp) # plots rance of influence

# models with anova methods can also be summarized this way
anova(plongley) 

# plots different replications
plot(plongley) # plots the perturbed replications individually, pausing in between
plot(sp) # plots boxplots of the distribution of the coefficients under perturbation

# plots anova results (where applicable)
plot(anova(plongley))


# look in summary object to extract more ...
names(attributes(sp))

# print matrix of coefficients from all runs
coef= attr(sp,"coef.betas.m")
summary(coef)




